# RCS0010: Add blank line between declarations

| Property | Value   |
| -------- | ------- |
| Id       | RCS0010 |
| Severity | None    |

## Example

### Code with Diagnostic

```csharp
class Foo
{
    void M1()
    {
    } // RCS0010
    void M2()
    {
    } // RCS0010
    /// <summary>
    /// ...
    /// </summary>
    void M3()
    {
    } // RCS0010
    string P1 { get; set; } // RCS0010
    [Obsolete]
    string P2 { get; set; }
} // RCS0010
enum Bar
{
    A = 0, // RCS0010
    /// <summary>
    /// ...
    /// </summary>
    B = 1, // RCS0010
    [Obsolete]
    C = 2,
}
```

### Code with Fix

```csharp
class Foo
{
    void M1()
    {
    }

    void M2()
    {
    }

    /// <summary>
    /// ...
    /// </summary>
    void M3()
    {
    }

    string P1 { get; set; }

    [Obsolete]
    string P2 { get; set; }
}

enum Bar
{
    A = 0,

    /// <summary>
    /// ...
    /// </summary>
    B = 1,

    [Obsolete]
    C = 2,
}
```

## Remarks

This rule does not enforce an blank line between two single-line declaration.

## Applies to

* [Roslynator.Formatting.Analyzers](https://www.nuget.org/packages/Roslynator.Formatting.Analyzers)


*\(Generated with [DotMarkdown](http://github.com/JosefPihrt/DotMarkdown)\)*