# RCS0053: Fix formatting of a list

| Property | Value   |
| -------- | ------- |
| Id       | RCS0053 |
| Severity | None    |

## Summary


      This analyzer:
* fixes indentation of argument/parameter list and similar lists
* formats each item in a multi-line list on a separate line

Following formats are considered as valid (for a parameter list):
```cs
void M(object x, object y)
{
}
```
```cs
void M(
    object x, object y)
{
}
```
```cs
void M(
    object x,
    object y)
{
}
```


## Examples

### Code with Diagnostic

```csharp
void M(
    object x,
        object y)
{
}
```

### Code with Fix

```csharp
void M(
    object x,
    object y)
{
}
```

- - -

### Code with Diagnostic

```csharp
void M(object x,
    object y)
{
}
```

### Code with Fix

```csharp
void M(
    object x,
    object y)
{
}
```

- - -

### Code with Diagnostic

```csharp
void M(object x,
       object y)
{
}
```

### Code with Fix

```csharp
void M(
    object x,
    object y)
{
}
```

- - -

### Code with Diagnostic

```csharp
void M(
    object x,
    object y, object z)
{
}
```

### Code with Fix

```csharp
void M(
    object x,
    object y,
    object z)
{
}
```

## Applies to

* [Roslynator.Formatting.Analyzers](https://www.nuget.org/packages/Roslynator.Formatting.Analyzers)


*\(Generated with [DotMarkdown](http://github.com/JosefPihrt/DotMarkdown)\)*